% prototype code on 9/17/17 by Xiaojing Ye (Georgia State Univ.)
% modified on 4/20/18 by Bin Li (South China Univ. of Tech)

% Contacts:
% 	Xiaojing Ye (xye@gsu.edu)
%   Bin Li (binlee@scut.edu.cn)

% Reference:
%   A Two-stage Algorithm for Joint Multimodal Image Reconstruction
%   Yunmei Chen, Bin Li, Xiaojing Ye
%   SIAM Journal on Imaging Sciences, 12 (3) , pp. 1425-1463, 2019.

%% compare with existing methods

clear; close all;

%% add data and solver paths
addpath('./data');
addpath('./solver');
addpath('./utils');

%% load data

load('./data/mr_brainweb_3mod.mat');

noise_std = 5;
verbose = 1;
[f, p] = gen_pf_data(U0, P, noise_std, verbose);

%% direct inverse of partial Fourier data

u_bp = zeros(size(f));
for k = 1:size(f,3)
    u_bp(:,:,k) = real(ifft2(f(:,:,k)));
end

%% edge based image reconsruction from partial Fourier data

wTV = 1e-4; maxiter = 100; etol = 1e-8;
[u_fro, out_fro] = edgerec_pf(f, p, wTV, maxiter, etol, 'fro', noise_std);

%% display reconstructed image

figure;
img = abs([vstack_img(U0), vstack_img(u_bp), vstack_img(u_fro)]);
imshow(img, []);
title('Left: True.   Middle: Zero-fill.   Right: EdgeRec.')