function u = edge2img_pf(f, p, uv, uh, wDATA)
% reconstruct image u from gradients uh and uv and partial Fourier (pf) data
% U = argmin_U ||DhU - Uh||^2 + ||DvU - Uv||_2^2 + wDATA*||PF(U)-f||_2^2
% INPUT:
%       f: partial Fourier data of image, size = (nr, nc, nimg)
%       p: undersampling pattern in Fourier space, binary, same size as f
%       uv, uh: reconstructed edges of u
%       wDATA: weight of data term in reconstruction of image
% OUTPUT:
%       u: image to be reconstructed, size = (nr, nc, nimg)

[nr, nc, nimg] = size(f);
u = zeros(nr, nc, nimg);

% create Fourier transform of gradient (forward finite diff) operators
FDv = psf2otf([1;-1], [nr,nc]);
FDh = psf2otf([1,-1], [nr,nc]);

FDsq = abs(FDv).^2+abs(FDh).^2;

% reconstruct all images to form u
for k = 1:nimg
    denom = FDsq + wDATA*p(:,:,k);
    numer = conj(FDv).*fft2(uv(:,:,k)) + conj(FDh).*fft2(uh(:,:,k)) + wDATA*p(:,:,k).*f(:,:,k);
    u(:,:,k) = real(ifft2(numer./denom));
end