function [f, p] = gen_pf_data(U0, P, noise_std, verbose)
% generate (noisy) partial Fourier data

[nr, nc, nimg] = size(U0);

% create partial Fourier data
f = zeros(nr, nc, nimg);
p = zeros(nr, nc, nimg);
for k = 1:nimg
    p(:,:,k) = P;
    f(:,:,k) = fft2(U0(:,:,k));
end
f = f.*p; % undersampled data

% add noise to partial Fourier data
noise = noise_std * p .* (randn(nr, nc, nimg) + 1i * randn(nr, nc, nimg)); 
f = f + noise;

if nargin > 3 && verbose
    fprintf('Sampling ratio = %.2f%%, Noise std = %.2f.\n', sum(p(:))/numel(p)*100, noise_std);
end