function [Xv,Xh] = shrink_mt2(Bv,Bh,tau)
% shrinkage operator that solves pointwisely (corrected version)
% minimize_X tau*|X|_2 + (1/2) * |X-B|^2

[nr, nc, nimg] = size(Bv);

Xv = zeros(nr, nc, nimg);
Xh = zeros(nr, nc, nimg);

b = zeros(2, nimg);

for ii = 1 : nr
    for jj = 1 : nc
        
        b(1,:) = Bv(ii,jj,:);
        b(2,:) = Bh(ii,jj,:);
        
        if nimg == 2
            [U, S, V] = svd2x2(b); % closed form svd for 2x2 matrix
        else
            [U, S, V] = svd(b,'econ');
        end
        
        s = diag(S);
                
        if sum(s) <= tau
            x = zeros(size(b));
        else
            s = projsplx(s/tau);
            x = b - tau * (U * diag(s) * V');
        end
        
        Xv(ii, jj, :) = x(1,:);
        Xh(ii, jj, :) = x(2,:);
        
    end
end
