function [Xv,Xh] = shrink_nuc(Bv,Bh,tau)
% shrinkage operator that solves pointwisely
% minimize_X tau*|X|_* + (1/2) * |X-B|^2
% where |X|_* is the nuclear norm of X

[nr, nc, nimg] = size(Bv);

Xv = zeros(nr, nc, nimg);
Xh = zeros(nr, nc, nimg);

b = zeros(2, nimg);

for ii = 1 : nr
    for jj = 1 : nc
        
        b(1,:) = Bv(ii,jj,:);
        b(2,:) = Bh(ii,jj,:);
        
        if nimg == 2
            [U, S, V] = svd2x2(b); % closed form svd for 2x2 matrix
        else
            [U, S, V] = svd(b);
        end
        
        x = U * max(S-tau, 0) * V';
        
        Xv(ii, jj, :) = x(1,:);
        Xh(ii, jj, :) = x(2,:);
        
    end
end